@@ -2,20 +2,18 @@
 ----------------------------------------------------------------------*/
 /**
  * @file		iutest_port_c.h
- * @brief		iris unit portable t@C
+ * @brief		iris unit portable
  *
  * @author		t.sirayanagi
- * @version		1.0
- *
  * @par			copyright
- * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 /*----------------------------------------------------------------------
 ======================================================================*/
-#ifndef INCG_IRIS_iutest_port_c_H_6D5DBD9D_C830_4415_957D_D38D69AEE35B_
-#define INCG_IRIS_iutest_port_c_H_6D5DBD9D_C830_4415_957D_D38D69AEE35B_
+#ifndef INCG_IRIS_IUTEST_PORT_C_H_6D5DBD9D_C830_4415_957D_D38D69AEE35B_
+#define INCG_IRIS_IUTEST_PORT_C_H_6D5DBD9D_C830_4415_957D_D38D69AEE35B_
 
 /* include ===========================================================*/
 #include "iutest_compiler_c.h"
@@ -38,6 +36,10 @@ IUTEST_ATTRIBUTE_UNUSED_ iuBOOL iuTestOS_GetEnvironmentVariable(const char* name
 
 IUTEST_ATTRIBUTE_UNUSED_ iuBOOL iuTestOS_GetEnvironmentInt(const char* name, int* value);
 
+IUTEST_ATTRIBUTE_UNUSED_ void iuAbort(void);
+
+IUTEST_ATTRIBUTE_UNUSED_ void iuExit(int exit_code);
+
 #if defined(IUTEST_OS_WINDOWS)
 
 /**
