@@ -2,20 +2,18 @@
 ----------------------------------------------------------------------*/
 /**
  * @file		iutest_regex_c.h
- * @brief		iris unit test p regex t@C
+ * @brief		iris unit test regex
  *
  * @author		t.sirayanagi
- * @version		1.0
- *
  * @par			copyright
- * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 /*----------------------------------------------------------------------
 ======================================================================*/
-#ifndef INCG_IRIS_iutest_regex_C_H_1575CB44_189A_4248_B305_DB4882E3BFC2_
-#define INCG_IRIS_iutest_regex_C_H_1575CB44_189A_4248_B305_DB4882E3BFC2_
+#ifndef INCG_IRIS_IUTEST_REGEX_C_H_1575CB44_189A_4248_B305_DB4882E3BFC2_
+#define INCG_IRIS_IUTEST_REGEX_C_H_1575CB44_189A_4248_B305_DB4882E3BFC2_
 
 IUTEST_EXTERN_C_BEGIN()
 
