@@ -2,20 +2,18 @@
 ----------------------------------------------------------------------*/
 /**
  * @file		iutest_xml_file_c.h
- * @brief		iris unit test XML t@Cwp[ t@C
+ * @brief		iris unit test XML file helper
  *
  * @author		t.sirayanagi
- * @version		1.0
- *
  * @par			copyright
- * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 /*----------------------------------------------------------------------
 ======================================================================*/
-#ifndef INCG_IRIS_iutest_xml_file_C_H_E22B02D7_E9E7_412c_B609_DC3D9C66895D_
-#define INCG_IRIS_iutest_xml_file_C_H_E22B02D7_E9E7_412c_B609_DC3D9C66895D_
+#ifndef INCG_IRIS_IUTEST_XML_FILE_C_H_E22B02D7_E9E7_412C_B609_DC3D9C66895D_
+#define INCG_IRIS_IUTEST_XML_FILE_C_H_E22B02D7_E9E7_412C_B609_DC3D9C66895D_
 
 /* include ===========================================================*/
 #include "iutest_string_c.h"
