@@ -2,14 +2,12 @@
 ----------------------------------------------------------------------*/
 /**
  * @file		iutest_c.h
- * @brief		iris unit test t@C
+ * @brief		iris unit test
  *
  * @author		t.sirayanagi
- * @version		1.0
- *
  * @par			copyright
- * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
  * 
  * @see			iutest_ver_c.h
@@ -18,8 +16,8 @@
 */
 /*----------------------------------------------------------------------
 ======================================================================*/
-#ifndef INCG_IRIS_iutest_c_H_
-#define INCG_IRIS_iutest_c_H_
+#ifndef INCG_IRIS_IUTEST_C_H_
+#define INCG_IRIS_IUTEST_C_H_
 
 /* include ===========================================================*/
 #include "iutest_ver_c.h"
@@ -84,7 +82,7 @@
  * @ingroup	TESTDEF
  * @brief	ׂẴeXgs
 */
-#define IUTEST_RUN_ALL_TESTS()						iuUnitTest_Run()
+#define IUTEST_RUN_ALL_TESTS()						iuTestRun()
 
 /**
  * @ingroup TESTDEF
@@ -131,6 +129,15 @@
 #  define IUTEST_ADD_FAILURE_AT(file, line)			IIUT_ADD_FAILURE_AT(file, line)
 #endif
 
+/**
+ * @ingroup		IUTEST_UTIL
+ * @brief		eXg̖IȃXLbv
+ * @details		IɃXLbv񍐂܂
+*/
+#ifndef IUTEST_SKIP
+#  define IUTEST_SKIP()								IUTEST_TEST_SKIP()
+#endif
+
 /**
  * @defgroup	IUTEST_ASSERT_	AT[V(ASSERT)
  * @brief		eXgLq}N
@@ -722,18 +729,32 @@ static void iuTestInitialize(void);
 */
 static IUTEST_ATTRIBUTE_UNUSED_ void	iuInitIrisUnitTestA(int* argc, char** argv)
 {
+#if IUTEST_C_HAS_ENVIRONMENTSVAR_OPTION
 	iuTestEnv_LoadEnviromentVariable();
+#endif
+#if IUTEST_C_HAS_COMMANDLINE_OPTION
 	iuTestEnv_ParseCommandLineA(argc, argv);
+#else
+	IUTEST_UNUSED_VAR(argc);
+	IUTEST_UNUSED_VAR(argv);
+#endif
 	iuTestInitialize();
 }
 #if IUTEST_C_HAS_WCHAR_T
 /**
  * @brief	eXg̏
 */
-static IUTEST_ATTRIBUTE_UNUSED_ void	iuInitIrisUnitTestW(int* argc, wchar_t** argv)
+static IUTEST_ATTRIBUTE_UNUSED_ void iuInitIrisUnitTestW(int* argc, wchar_t** argv)
 {
+#if IUTEST_C_HAS_ENVIRONMENTSVAR_OPTION
 	iuTestEnv_LoadEnviromentVariable();
+#endif
+#if IUTEST_C_HAS_COMMANDLINE_OPTION
 	iuTestEnv_ParseCommandLineW(argc, argv);
+#else
+	IUTEST_UNUSED_VAR(argc);
+	IUTEST_UNUSED_VAR(argv);
+#endif
 	iuTestInitialize();
 }
 #endif
@@ -748,33 +769,47 @@ static IUTEST_ATTRIBUTE_UNUSED_ void	iuInitIrisUnitTestW(int* argc, wchar_t** ar
 /**
  * @biref	eXg̏iʍj
 */
-static void iuTestInitialize(void)
+static IUTEST_ATTRIBUTE_UNUSED_ void iuTestInitialize(void)
 {
+#if IUTEST_C_HAS_CONSOLEOUT
+	iuUnitTest_ReleaseTestListener(&iuUnitTest_GetInstance()->def_printer);
 	{
 		iuTestListener* listener = iuTestListener_MakeListener(&iuUnitTest_GetInstance()->def_printer
-			, iuTestDefaultPrinter_OnTestProgramStart
-			, iuTestDefaultPrinter_OnTestIterationStart
-			, NULL
-			, NULL
-			, iuTestDefaultPrinter_OnTestCaseStart
-			, iuTestDefaultPrinter_OnTestStart
-			, iuTestDefaultPrinter_OnTestPartResult
-			, iuTestDefaultPrinter_OnTestRecordProperty
-			, iuTestDefaultPrinter_OnTestEnd
-			, iuTestDefaultPrinter_OnTestCaseEnd
-			, NULL
-			, NULL
-			, iuTestDefaultPrinter_OnTestIterationEnd
-			, iuTestDefaultPrinter_OnTestProgramEnd
-			);
-		if( listener != NULL )
+		, iuTestDefaultPrinter_OnTestProgramStart
+		, iuTestDefaultPrinter_OnTestIterationStart
+		, NULL
+		, NULL
+		, iuTestDefaultPrinter_OnTestCaseStart
+		, iuTestDefaultPrinter_OnTestStart
+		, iuTestDefaultPrinter_OnTestPartResult
+		, iuTestDefaultPrinter_OnTestRecordProperty
+		, iuTestDefaultPrinter_OnTestEnd
+		, iuTestDefaultPrinter_OnTestCaseEnd
+		, NULL
+		, NULL
+		, iuTestDefaultPrinter_OnTestIterationEnd
+		, iuTestDefaultPrinter_OnTestProgramEnd
+		);
+		if(listener != NULL)
 		{
-			iuUnitTest_AddTestListener(listener);
+			iuUnitTest_AppendTestListener(listener);
 		}
 	}
-	if( iuTestEnv_IsEnableFlag(IUTESTENV_OUTPUT_XML_REPORT) )
+#endif
+	iuUnitTest_Init();
+}
+
+/**
+ * @brief	eXg̎s
+*/
+static IUTEST_ATTRIBUTE_UNUSED_ int iuTestRun(void)
+{
+#if IUTEST_C_HAS_DEFAULT_XML_GENERATOR
+	iuUnitTest_ReleaseTestListener(&iuUnitTest_GetInstance()->def_xml_generator);
+	if(iuTestEnv_IsEnableOutputXml())
 	{
-		iuTestListener* listener = iuTestListener_MakeListener(&iuUnitTest_GetInstance()->def_xml_generator
+		{
+			iuTestListener* listener = iuTestListener_MakeListener(&iuUnitTest_GetInstance()->def_xml_generator
 			, iuTestDefaultXMLGenerator_OnTestProgramStart
 			, iuTestDefaultXMLGenerator_OnTestIterationStart
 			, NULL
@@ -790,12 +825,14 @@ static void iuTestInitialize(void)
 			, iuTestDefaultXMLGenerator_OnTestIterationEnd
 			, iuTestDefaultXMLGenerator_OnTestProgramEnd
 			);
-		if( listener != NULL )
-		{
-			iuUnitTest_AddTestListener(listener);
+			if(listener != NULL)
+			{
+				iuUnitTest_AppendTestListener(listener);
+			}
 		}
 	}
-	iuUnitTest_Init();
+#endif
+	return iuUnitTest_Run();
 }
 
 #endif
