@@ -5,11 +5,9 @@
  * @brief		iutest assertion only test
  *
  * @author		t.sirayanagi
- * @version		1.0
- *
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 /*----------------------------------------------------------------------
@@ -20,6 +18,8 @@
 
 IUTEST_C_WORKSPACE();
 
+#if IUTEST_C_HAS_CONSOLEOUT
+
 static int call_printf = 0;
 
 int test_vprintf(const char* fmt, va_list va)
@@ -35,20 +35,25 @@ void Test(void)
 	IUTEST_ASSERT_RVALUE_EQ(0, 1);
 }
 
+#endif
+
 #ifdef UNICODE
 int wmain(int argc, wchar_t* argv[])
 #else
 int main(int argc, char* argv[])
 #endif
 {
+#if IUTEST_C_HAS_CONSOLEOUT
 	iuUnitTest_SetVPrintfFunction(test_vprintf);
-
-	IUTEST_INIT(&argc, argv);
+#endif
 	
+	IUTEST_INIT(&argc, argv);
+#if IUTEST_C_HAS_CONSOLEOUT
 	Test();
 	
 	if( call_printf == 0 ) return 1;
-	printf("*** Successful ***\n");
+#endif
+	IUTEST_PRINTF("*** Successful ***\n");
 	return 0;
 }
 
